@@ -8,7 +8,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = 0.04; 
+our $VERSION = 0.05; 
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -36,7 +36,7 @@ Syntax::Keyword::Combine::Keys - The great new Syntax::Keyword::Combine::Keys!
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -58,8 +58,8 @@ Perhaps a little code snippet.
 	....
 
 	my %hash = ckeys {
-		$_ => $hash1{$_} || $hash2->{$_};
-	} %{$hash1}, %hash2;
+		$_ => $HASH{$_}->{value};
+	} %{$hash1}, %hash2, e => { value => 500 };
 	
 =head1 AUTHOR
 
